# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class GeneralInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'current_time': 'datetime',
        'with_notary': 'bool',
        'with_chartmuseum': 'bool',
        'registry_url': 'str',
        'external_url': 'str',
        'auth_mode': 'str',
        'project_creation_restriction': 'str',
        'self_registration': 'bool',
        'has_ca_root': 'bool',
        'harbor_version': 'str',
        'registry_storage_provider_name': 'str',
        'read_only': 'bool',
        'notification_enable': 'bool',
        'authproxy_settings': 'AuthproxySetting'
    }

    attribute_map = {
        'current_time': 'current_time',
        'with_notary': 'with_notary',
        'with_chartmuseum': 'with_chartmuseum',
        'registry_url': 'registry_url',
        'external_url': 'external_url',
        'auth_mode': 'auth_mode',
        'project_creation_restriction': 'project_creation_restriction',
        'self_registration': 'self_registration',
        'has_ca_root': 'has_ca_root',
        'harbor_version': 'harbor_version',
        'registry_storage_provider_name': 'registry_storage_provider_name',
        'read_only': 'read_only',
        'notification_enable': 'notification_enable',
        'authproxy_settings': 'authproxy_settings'
    }

    def __init__(self, current_time=None, with_notary=None, with_chartmuseum=None, registry_url=None, external_url=None, auth_mode=None, project_creation_restriction=None, self_registration=None, has_ca_root=None, harbor_version=None, registry_storage_provider_name=None, read_only=None, notification_enable=None, authproxy_settings=None, _configuration=None):  # noqa: E501
        """GeneralInfo - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._current_time = None
        self._with_notary = None
        self._with_chartmuseum = None
        self._registry_url = None
        self._external_url = None
        self._auth_mode = None
        self._project_creation_restriction = None
        self._self_registration = None
        self._has_ca_root = None
        self._harbor_version = None
        self._registry_storage_provider_name = None
        self._read_only = None
        self._notification_enable = None
        self._authproxy_settings = None
        self.discriminator = None

        if current_time is not None:
            self.current_time = current_time
        if with_notary is not None:
            self.with_notary = with_notary
        if with_chartmuseum is not None:
            self.with_chartmuseum = with_chartmuseum
        if registry_url is not None:
            self.registry_url = registry_url
        if external_url is not None:
            self.external_url = external_url
        if auth_mode is not None:
            self.auth_mode = auth_mode
        if project_creation_restriction is not None:
            self.project_creation_restriction = project_creation_restriction
        if self_registration is not None:
            self.self_registration = self_registration
        if has_ca_root is not None:
            self.has_ca_root = has_ca_root
        if harbor_version is not None:
            self.harbor_version = harbor_version
        if registry_storage_provider_name is not None:
            self.registry_storage_provider_name = registry_storage_provider_name
        if read_only is not None:
            self.read_only = read_only
        if notification_enable is not None:
            self.notification_enable = notification_enable
        if authproxy_settings is not None:
            self.authproxy_settings = authproxy_settings

    @property
    def current_time(self):
        """Gets the current_time of this GeneralInfo.  # noqa: E501

        The current time of the server.  # noqa: E501

        :return: The current_time of this GeneralInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._current_time

    @current_time.setter
    def current_time(self, current_time):
        """Sets the current_time of this GeneralInfo.

        The current time of the server.  # noqa: E501

        :param current_time: The current_time of this GeneralInfo.  # noqa: E501
        :type: datetime
        """

        self._current_time = current_time

    @property
    def with_notary(self):
        """Gets the with_notary of this GeneralInfo.  # noqa: E501

        If the Harbor instance is deployed with nested notary.  # noqa: E501

        :return: The with_notary of this GeneralInfo.  # noqa: E501
        :rtype: bool
        """
        return self._with_notary

    @with_notary.setter
    def with_notary(self, with_notary):
        """Sets the with_notary of this GeneralInfo.

        If the Harbor instance is deployed with nested notary.  # noqa: E501

        :param with_notary: The with_notary of this GeneralInfo.  # noqa: E501
        :type: bool
        """

        self._with_notary = with_notary

    @property
    def with_chartmuseum(self):
        """Gets the with_chartmuseum of this GeneralInfo.  # noqa: E501

        If the Harbor instance is deployed with nested chartmuseum.  # noqa: E501

        :return: The with_chartmuseum of this GeneralInfo.  # noqa: E501
        :rtype: bool
        """
        return self._with_chartmuseum

    @with_chartmuseum.setter
    def with_chartmuseum(self, with_chartmuseum):
        """Sets the with_chartmuseum of this GeneralInfo.

        If the Harbor instance is deployed with nested chartmuseum.  # noqa: E501

        :param with_chartmuseum: The with_chartmuseum of this GeneralInfo.  # noqa: E501
        :type: bool
        """

        self._with_chartmuseum = with_chartmuseum

    @property
    def registry_url(self):
        """Gets the registry_url of this GeneralInfo.  # noqa: E501

        The url of registry against which the docker command should be issued.  # noqa: E501

        :return: The registry_url of this GeneralInfo.  # noqa: E501
        :rtype: str
        """
        return self._registry_url

    @registry_url.setter
    def registry_url(self, registry_url):
        """Sets the registry_url of this GeneralInfo.

        The url of registry against which the docker command should be issued.  # noqa: E501

        :param registry_url: The registry_url of this GeneralInfo.  # noqa: E501
        :type: str
        """

        self._registry_url = registry_url

    @property
    def external_url(self):
        """Gets the external_url of this GeneralInfo.  # noqa: E501

        The external URL of Harbor, with protocol.  # noqa: E501

        :return: The external_url of this GeneralInfo.  # noqa: E501
        :rtype: str
        """
        return self._external_url

    @external_url.setter
    def external_url(self, external_url):
        """Sets the external_url of this GeneralInfo.

        The external URL of Harbor, with protocol.  # noqa: E501

        :param external_url: The external_url of this GeneralInfo.  # noqa: E501
        :type: str
        """

        self._external_url = external_url

    @property
    def auth_mode(self):
        """Gets the auth_mode of this GeneralInfo.  # noqa: E501

        The auth mode of current Harbor instance.  # noqa: E501

        :return: The auth_mode of this GeneralInfo.  # noqa: E501
        :rtype: str
        """
        return self._auth_mode

    @auth_mode.setter
    def auth_mode(self, auth_mode):
        """Sets the auth_mode of this GeneralInfo.

        The auth mode of current Harbor instance.  # noqa: E501

        :param auth_mode: The auth_mode of this GeneralInfo.  # noqa: E501
        :type: str
        """

        self._auth_mode = auth_mode

    @property
    def project_creation_restriction(self):
        """Gets the project_creation_restriction of this GeneralInfo.  # noqa: E501

        Indicate who can create projects, it could be 'adminonly' or 'everyone'.  # noqa: E501

        :return: The project_creation_restriction of this GeneralInfo.  # noqa: E501
        :rtype: str
        """
        return self._project_creation_restriction

    @project_creation_restriction.setter
    def project_creation_restriction(self, project_creation_restriction):
        """Sets the project_creation_restriction of this GeneralInfo.

        Indicate who can create projects, it could be 'adminonly' or 'everyone'.  # noqa: E501

        :param project_creation_restriction: The project_creation_restriction of this GeneralInfo.  # noqa: E501
        :type: str
        """

        self._project_creation_restriction = project_creation_restriction

    @property
    def self_registration(self):
        """Gets the self_registration of this GeneralInfo.  # noqa: E501

        Indicate whether the Harbor instance enable user to register himself.  # noqa: E501

        :return: The self_registration of this GeneralInfo.  # noqa: E501
        :rtype: bool
        """
        return self._self_registration

    @self_registration.setter
    def self_registration(self, self_registration):
        """Sets the self_registration of this GeneralInfo.

        Indicate whether the Harbor instance enable user to register himself.  # noqa: E501

        :param self_registration: The self_registration of this GeneralInfo.  # noqa: E501
        :type: bool
        """

        self._self_registration = self_registration

    @property
    def has_ca_root(self):
        """Gets the has_ca_root of this GeneralInfo.  # noqa: E501

        Indicate whether there is a ca root cert file ready for download in the file system.  # noqa: E501

        :return: The has_ca_root of this GeneralInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_ca_root

    @has_ca_root.setter
    def has_ca_root(self, has_ca_root):
        """Sets the has_ca_root of this GeneralInfo.

        Indicate whether there is a ca root cert file ready for download in the file system.  # noqa: E501

        :param has_ca_root: The has_ca_root of this GeneralInfo.  # noqa: E501
        :type: bool
        """

        self._has_ca_root = has_ca_root

    @property
    def harbor_version(self):
        """Gets the harbor_version of this GeneralInfo.  # noqa: E501

        The build version of Harbor.  # noqa: E501

        :return: The harbor_version of this GeneralInfo.  # noqa: E501
        :rtype: str
        """
        return self._harbor_version

    @harbor_version.setter
    def harbor_version(self, harbor_version):
        """Sets the harbor_version of this GeneralInfo.

        The build version of Harbor.  # noqa: E501

        :param harbor_version: The harbor_version of this GeneralInfo.  # noqa: E501
        :type: str
        """

        self._harbor_version = harbor_version

    @property
    def registry_storage_provider_name(self):
        """Gets the registry_storage_provider_name of this GeneralInfo.  # noqa: E501

        The storage provider's name of Harbor registry  # noqa: E501

        :return: The registry_storage_provider_name of this GeneralInfo.  # noqa: E501
        :rtype: str
        """
        return self._registry_storage_provider_name

    @registry_storage_provider_name.setter
    def registry_storage_provider_name(self, registry_storage_provider_name):
        """Sets the registry_storage_provider_name of this GeneralInfo.

        The storage provider's name of Harbor registry  # noqa: E501

        :param registry_storage_provider_name: The registry_storage_provider_name of this GeneralInfo.  # noqa: E501
        :type: str
        """

        self._registry_storage_provider_name = registry_storage_provider_name

    @property
    def read_only(self):
        """Gets the read_only of this GeneralInfo.  # noqa: E501

        The flag to indicate whether Harbor is in readonly mode.  # noqa: E501

        :return: The read_only of this GeneralInfo.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this GeneralInfo.

        The flag to indicate whether Harbor is in readonly mode.  # noqa: E501

        :param read_only: The read_only of this GeneralInfo.  # noqa: E501
        :type: bool
        """

        self._read_only = read_only

    @property
    def notification_enable(self):
        """Gets the notification_enable of this GeneralInfo.  # noqa: E501

        The flag to indicate whether notification mechanism is enabled on Harbor instance.  # noqa: E501

        :return: The notification_enable of this GeneralInfo.  # noqa: E501
        :rtype: bool
        """
        return self._notification_enable

    @notification_enable.setter
    def notification_enable(self, notification_enable):
        """Sets the notification_enable of this GeneralInfo.

        The flag to indicate whether notification mechanism is enabled on Harbor instance.  # noqa: E501

        :param notification_enable: The notification_enable of this GeneralInfo.  # noqa: E501
        :type: bool
        """

        self._notification_enable = notification_enable

    @property
    def authproxy_settings(self):
        """Gets the authproxy_settings of this GeneralInfo.  # noqa: E501

        The setting of auth proxy this is only available when Harbor relies on authproxy for authentication.  # noqa: E501

        :return: The authproxy_settings of this GeneralInfo.  # noqa: E501
        :rtype: AuthproxySetting
        """
        return self._authproxy_settings

    @authproxy_settings.setter
    def authproxy_settings(self, authproxy_settings):
        """Sets the authproxy_settings of this GeneralInfo.

        The setting of auth proxy this is only available when Harbor relies on authproxy for authentication.  # noqa: E501

        :param authproxy_settings: The authproxy_settings of this GeneralInfo.  # noqa: E501
        :type: AuthproxySetting
        """

        self._authproxy_settings = authproxy_settings

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GeneralInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GeneralInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GeneralInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ProjectReq(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'project_name': 'str',
        'public': 'bool',
        'metadata': 'ProjectMetadata',
        'cve_allowlist': 'CVEAllowlist',
        'storage_limit': 'int',
        'registry_id': 'int'
    }

    attribute_map = {
        'project_name': 'project_name',
        'public': 'public',
        'metadata': 'metadata',
        'cve_allowlist': 'cve_allowlist',
        'storage_limit': 'storage_limit',
        'registry_id': 'registry_id'
    }

    def __init__(self, project_name=None, public=None, metadata=None, cve_allowlist=None, storage_limit=None, registry_id=None, _configuration=None):  # noqa: E501
        """ProjectReq - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._project_name = None
        self._public = None
        self._metadata = None
        self._cve_allowlist = None
        self._storage_limit = None
        self._registry_id = None
        self.discriminator = None

        if project_name is not None:
            self.project_name = project_name
        if public is not None:
            self.public = public
        if metadata is not None:
            self.metadata = metadata
        if cve_allowlist is not None:
            self.cve_allowlist = cve_allowlist
        if storage_limit is not None:
            self.storage_limit = storage_limit
        if registry_id is not None:
            self.registry_id = registry_id

    @property
    def project_name(self):
        """Gets the project_name of this ProjectReq.  # noqa: E501

        The name of the project.  # noqa: E501

        :return: The project_name of this ProjectReq.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this ProjectReq.

        The name of the project.  # noqa: E501

        :param project_name: The project_name of this ProjectReq.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                project_name is not None and len(project_name) > 255):
            raise ValueError("Invalid value for `project_name`, length must be less than or equal to `255`")  # noqa: E501

        self._project_name = project_name

    @property
    def public(self):
        """Gets the public of this ProjectReq.  # noqa: E501

        deprecated, reserved for project creation in replication  # noqa: E501

        :return: The public of this ProjectReq.  # noqa: E501
        :rtype: bool
        """
        return self._public

    @public.setter
    def public(self, public):
        """Sets the public of this ProjectReq.

        deprecated, reserved for project creation in replication  # noqa: E501

        :param public: The public of this ProjectReq.  # noqa: E501
        :type: bool
        """

        self._public = public

    @property
    def metadata(self):
        """Gets the metadata of this ProjectReq.  # noqa: E501

        The metadata of the project.  # noqa: E501

        :return: The metadata of this ProjectReq.  # noqa: E501
        :rtype: ProjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this ProjectReq.

        The metadata of the project.  # noqa: E501

        :param metadata: The metadata of this ProjectReq.  # noqa: E501
        :type: ProjectMetadata
        """

        self._metadata = metadata

    @property
    def cve_allowlist(self):
        """Gets the cve_allowlist of this ProjectReq.  # noqa: E501

        The CVE allowlist of the project.  # noqa: E501

        :return: The cve_allowlist of this ProjectReq.  # noqa: E501
        :rtype: CVEAllowlist
        """
        return self._cve_allowlist

    @cve_allowlist.setter
    def cve_allowlist(self, cve_allowlist):
        """Sets the cve_allowlist of this ProjectReq.

        The CVE allowlist of the project.  # noqa: E501

        :param cve_allowlist: The cve_allowlist of this ProjectReq.  # noqa: E501
        :type: CVEAllowlist
        """

        self._cve_allowlist = cve_allowlist

    @property
    def storage_limit(self):
        """Gets the storage_limit of this ProjectReq.  # noqa: E501

        The storage quota of the project.  # noqa: E501

        :return: The storage_limit of this ProjectReq.  # noqa: E501
        :rtype: int
        """
        return self._storage_limit

    @storage_limit.setter
    def storage_limit(self, storage_limit):
        """Sets the storage_limit of this ProjectReq.

        The storage quota of the project.  # noqa: E501

        :param storage_limit: The storage_limit of this ProjectReq.  # noqa: E501
        :type: int
        """

        self._storage_limit = storage_limit

    @property
    def registry_id(self):
        """Gets the registry_id of this ProjectReq.  # noqa: E501

        The ID of referenced registry when creating the proxy cache project  # noqa: E501

        :return: The registry_id of this ProjectReq.  # noqa: E501
        :rtype: int
        """
        return self._registry_id

    @registry_id.setter
    def registry_id(self, registry_id):
        """Sets the registry_id of this ProjectReq.

        The ID of referenced registry when creating the proxy cache project  # noqa: E501

        :param registry_id: The registry_id of this ProjectReq.  # noqa: E501
        :type: int
        """

        self._registry_id = registry_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProjectReq, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectReq):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProjectReq):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class RobotCreate(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'secret': 'str',
        'level': 'str',
        'disable': 'bool',
        'duration': 'int',
        'permissions': 'list[RobotPermission]'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'secret': 'secret',
        'level': 'level',
        'disable': 'disable',
        'duration': 'duration',
        'permissions': 'permissions'
    }

    def __init__(self, name=None, description=None, secret=None, level=None, disable=None, duration=None, permissions=None, _configuration=None):  # noqa: E501
        """RobotCreate - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._description = None
        self._secret = None
        self._level = None
        self._disable = None
        self._duration = None
        self._permissions = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if secret is not None:
            self.secret = secret
        if level is not None:
            self.level = level
        if disable is not None:
            self.disable = disable
        if duration is not None:
            self.duration = duration
        if permissions is not None:
            self.permissions = permissions

    @property
    def name(self):
        """Gets the name of this RobotCreate.  # noqa: E501

        The name of the tag  # noqa: E501

        :return: The name of this RobotCreate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RobotCreate.

        The name of the tag  # noqa: E501

        :param name: The name of this RobotCreate.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this RobotCreate.  # noqa: E501

        The description of the robot  # noqa: E501

        :return: The description of this RobotCreate.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RobotCreate.

        The description of the robot  # noqa: E501

        :param description: The description of this RobotCreate.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def secret(self):
        """Gets the secret of this RobotCreate.  # noqa: E501

        The secret of the robot  # noqa: E501

        :return: The secret of this RobotCreate.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this RobotCreate.

        The secret of the robot  # noqa: E501

        :param secret: The secret of this RobotCreate.  # noqa: E501
        :type: str
        """

        self._secret = secret

    @property
    def level(self):
        """Gets the level of this RobotCreate.  # noqa: E501

        The level of the robot, project or system  # noqa: E501

        :return: The level of this RobotCreate.  # noqa: E501
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this RobotCreate.

        The level of the robot, project or system  # noqa: E501

        :param level: The level of this RobotCreate.  # noqa: E501
        :type: str
        """

        self._level = level

    @property
    def disable(self):
        """Gets the disable of this RobotCreate.  # noqa: E501

        The disable status of the robot  # noqa: E501

        :return: The disable of this RobotCreate.  # noqa: E501
        :rtype: bool
        """
        return self._disable

    @disable.setter
    def disable(self, disable):
        """Sets the disable of this RobotCreate.

        The disable status of the robot  # noqa: E501

        :param disable: The disable of this RobotCreate.  # noqa: E501
        :type: bool
        """

        self._disable = disable

    @property
    def duration(self):
        """Gets the duration of this RobotCreate.  # noqa: E501

        The duration of the robot in days  # noqa: E501

        :return: The duration of this RobotCreate.  # noqa: E501
        :rtype: int
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        """Sets the duration of this RobotCreate.

        The duration of the robot in days  # noqa: E501

        :param duration: The duration of this RobotCreate.  # noqa: E501
        :type: int
        """

        self._duration = duration

    @property
    def permissions(self):
        """Gets the permissions of this RobotCreate.  # noqa: E501


        :return: The permissions of this RobotCreate.  # noqa: E501
        :rtype: list[RobotPermission]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """Sets the permissions of this RobotCreate.


        :param permissions: The permissions of this RobotCreate.  # noqa: E501
        :type: list[RobotPermission]
        """

        self._permissions = permissions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RobotCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RobotCreate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RobotCreate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Configurations(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auth_mode': 'str',
        'ldap_base_dn': 'str',
        'ldap_filter': 'str',
        'ldap_group_base_dn': 'str',
        'ldap_group_admin_dn': 'str',
        'ldap_group_attribute_name': 'str',
        'ldap_group_search_filter': 'str',
        'ldap_group_search_scope': 'int',
        'ldap_scope': 'int',
        'ldap_search_dn': 'str',
        'ldap_search_password': 'str',
        'ldap_timeout': 'int',
        'ldap_uid': 'str',
        'ldap_url': 'str',
        'ldap_verify_cert': 'bool',
        'ldap_group_membership_attribute': 'str',
        'project_creation_restriction': 'str',
        'read_only': 'bool',
        'self_registration': 'bool',
        'token_expiration': 'int',
        'uaa_client_id': 'str',
        'uaa_client_secret': 'str',
        'uaa_endpoint': 'str',
        'uaa_verify_cert': 'bool',
        'http_authproxy_endpoint': 'str',
        'http_authproxy_tokenreview_endpoint': 'str',
        'http_authproxy_admin_groups': 'str',
        'http_authproxy_admin_usernames': 'str',
        'http_authproxy_verify_cert': 'bool',
        'http_authproxy_skip_search': 'bool',
        'http_authproxy_server_certificate': 'str',
        'oidc_name': 'str',
        'oidc_endpoint': 'str',
        'oidc_client_id': 'str',
        'oidc_client_secret': 'str',
        'oidc_groups_claim': 'str',
        'oidc_admin_group': 'str',
        'oidc_group_filter': 'str',
        'oidc_scope': 'str',
        'oidc_user_claim': 'str',
        'oidc_verify_cert': 'bool',
        'oidc_auto_onboard': 'bool',
        'oidc_extra_redirect_parms': 'str',
        'robot_token_duration': 'int',
        'robot_name_prefix': 'str',
        'notification_enable': 'bool',
        'quota_per_project_enable': 'bool',
        'storage_per_project': 'int',
        'audit_log_forward_endpoint': 'str',
        'skip_audit_log_database': 'bool',
        'session_timeout': 'int'
    }

    attribute_map = {
        'auth_mode': 'auth_mode',
        'ldap_base_dn': 'ldap_base_dn',
        'ldap_filter': 'ldap_filter',
        'ldap_group_base_dn': 'ldap_group_base_dn',
        'ldap_group_admin_dn': 'ldap_group_admin_dn',
        'ldap_group_attribute_name': 'ldap_group_attribute_name',
        'ldap_group_search_filter': 'ldap_group_search_filter',
        'ldap_group_search_scope': 'ldap_group_search_scope',
        'ldap_scope': 'ldap_scope',
        'ldap_search_dn': 'ldap_search_dn',
        'ldap_search_password': 'ldap_search_password',
        'ldap_timeout': 'ldap_timeout',
        'ldap_uid': 'ldap_uid',
        'ldap_url': 'ldap_url',
        'ldap_verify_cert': 'ldap_verify_cert',
        'ldap_group_membership_attribute': 'ldap_group_membership_attribute',
        'project_creation_restriction': 'project_creation_restriction',
        'read_only': 'read_only',
        'self_registration': 'self_registration',
        'token_expiration': 'token_expiration',
        'uaa_client_id': 'uaa_client_id',
        'uaa_client_secret': 'uaa_client_secret',
        'uaa_endpoint': 'uaa_endpoint',
        'uaa_verify_cert': 'uaa_verify_cert',
        'http_authproxy_endpoint': 'http_authproxy_endpoint',
        'http_authproxy_tokenreview_endpoint': 'http_authproxy_tokenreview_endpoint',
        'http_authproxy_admin_groups': 'http_authproxy_admin_groups',
        'http_authproxy_admin_usernames': 'http_authproxy_admin_usernames',
        'http_authproxy_verify_cert': 'http_authproxy_verify_cert',
        'http_authproxy_skip_search': 'http_authproxy_skip_search',
        'http_authproxy_server_certificate': 'http_authproxy_server_certificate',
        'oidc_name': 'oidc_name',
        'oidc_endpoint': 'oidc_endpoint',
        'oidc_client_id': 'oidc_client_id',
        'oidc_client_secret': 'oidc_client_secret',
        'oidc_groups_claim': 'oidc_groups_claim',
        'oidc_admin_group': 'oidc_admin_group',
        'oidc_group_filter': 'oidc_group_filter',
        'oidc_scope': 'oidc_scope',
        'oidc_user_claim': 'oidc_user_claim',
        'oidc_verify_cert': 'oidc_verify_cert',
        'oidc_auto_onboard': 'oidc_auto_onboard',
        'oidc_extra_redirect_parms': 'oidc_extra_redirect_parms',
        'robot_token_duration': 'robot_token_duration',
        'robot_name_prefix': 'robot_name_prefix',
        'notification_enable': 'notification_enable',
        'quota_per_project_enable': 'quota_per_project_enable',
        'storage_per_project': 'storage_per_project',
        'audit_log_forward_endpoint': 'audit_log_forward_endpoint',
        'skip_audit_log_database': 'skip_audit_log_database',
        'session_timeout': 'session_timeout'
    }

    def __init__(self, auth_mode=None, ldap_base_dn=None, ldap_filter=None, ldap_group_base_dn=None, ldap_group_admin_dn=None, ldap_group_attribute_name=None, ldap_group_search_filter=None, ldap_group_search_scope=None, ldap_scope=None, ldap_search_dn=None, ldap_search_password=None, ldap_timeout=None, ldap_uid=None, ldap_url=None, ldap_verify_cert=None, ldap_group_membership_attribute=None, project_creation_restriction=None, read_only=None, self_registration=None, token_expiration=None, uaa_client_id=None, uaa_client_secret=None, uaa_endpoint=None, uaa_verify_cert=None, http_authproxy_endpoint=None, http_authproxy_tokenreview_endpoint=None, http_authproxy_admin_groups=None, http_authproxy_admin_usernames=None, http_authproxy_verify_cert=None, http_authproxy_skip_search=None, http_authproxy_server_certificate=None, oidc_name=None, oidc_endpoint=None, oidc_client_id=None, oidc_client_secret=None, oidc_groups_claim=None, oidc_admin_group=None, oidc_group_filter=None, oidc_scope=None, oidc_user_claim=None, oidc_verify_cert=None, oidc_auto_onboard=None, oidc_extra_redirect_parms=None, robot_token_duration=None, robot_name_prefix=None, notification_enable=None, quota_per_project_enable=None, storage_per_project=None, audit_log_forward_endpoint=None, skip_audit_log_database=None, session_timeout=None, _configuration=None):  # noqa: E501
        """Configurations - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._auth_mode = None
        self._ldap_base_dn = None
        self._ldap_filter = None
        self._ldap_group_base_dn = None
        self._ldap_group_admin_dn = None
        self._ldap_group_attribute_name = None
        self._ldap_group_search_filter = None
        self._ldap_group_search_scope = None
        self._ldap_scope = None
        self._ldap_search_dn = None
        self._ldap_search_password = None
        self._ldap_timeout = None
        self._ldap_uid = None
        self._ldap_url = None
        self._ldap_verify_cert = None
        self._ldap_group_membership_attribute = None
        self._project_creation_restriction = None
        self._read_only = None
        self._self_registration = None
        self._token_expiration = None
        self._uaa_client_id = None
        self._uaa_client_secret = None
        self._uaa_endpoint = None
        self._uaa_verify_cert = None
        self._http_authproxy_endpoint = None
        self._http_authproxy_tokenreview_endpoint = None
        self._http_authproxy_admin_groups = None
        self._http_authproxy_admin_usernames = None
        self._http_authproxy_verify_cert = None
        self._http_authproxy_skip_search = None
        self._http_authproxy_server_certificate = None
        self._oidc_name = None
        self._oidc_endpoint = None
        self._oidc_client_id = None
        self._oidc_client_secret = None
        self._oidc_groups_claim = None
        self._oidc_admin_group = None
        self._oidc_group_filter = None
        self._oidc_scope = None
        self._oidc_user_claim = None
        self._oidc_verify_cert = None
        self._oidc_auto_onboard = None
        self._oidc_extra_redirect_parms = None
        self._robot_token_duration = None
        self._robot_name_prefix = None
        self._notification_enable = None
        self._quota_per_project_enable = None
        self._storage_per_project = None
        self._audit_log_forward_endpoint = None
        self._skip_audit_log_database = None
        self._session_timeout = None
        self.discriminator = None

        if auth_mode is not None:
            self.auth_mode = auth_mode
        if ldap_base_dn is not None:
            self.ldap_base_dn = ldap_base_dn
        if ldap_filter is not None:
            self.ldap_filter = ldap_filter
        if ldap_group_base_dn is not None:
            self.ldap_group_base_dn = ldap_group_base_dn
        if ldap_group_admin_dn is not None:
            self.ldap_group_admin_dn = ldap_group_admin_dn
        if ldap_group_attribute_name is not None:
            self.ldap_group_attribute_name = ldap_group_attribute_name
        if ldap_group_search_filter is not None:
            self.ldap_group_search_filter = ldap_group_search_filter
        if ldap_group_search_scope is not None:
            self.ldap_group_search_scope = ldap_group_search_scope
        if ldap_scope is not None:
            self.ldap_scope = ldap_scope
        if ldap_search_dn is not None:
            self.ldap_search_dn = ldap_search_dn
        if ldap_search_password is not None:
            self.ldap_search_password = ldap_search_password
        if ldap_timeout is not None:
            self.ldap_timeout = ldap_timeout
        if ldap_uid is not None:
            self.ldap_uid = ldap_uid
        if ldap_url is not None:
            self.ldap_url = ldap_url
        if ldap_verify_cert is not None:
            self.ldap_verify_cert = ldap_verify_cert
        if ldap_group_membership_attribute is not None:
            self.ldap_group_membership_attribute = ldap_group_membership_attribute
        if project_creation_restriction is not None:
            self.project_creation_restriction = project_creation_restriction
        if read_only is not None:
            self.read_only = read_only
        if self_registration is not None:
            self.self_registration = self_registration
        if token_expiration is not None:
            self.token_expiration = token_expiration
        if uaa_client_id is not None:
            self.uaa_client_id = uaa_client_id
        if uaa_client_secret is not None:
            self.uaa_client_secret = uaa_client_secret
        if uaa_endpoint is not None:
            self.uaa_endpoint = uaa_endpoint
        if uaa_verify_cert is not None:
            self.uaa_verify_cert = uaa_verify_cert
        if http_authproxy_endpoint is not None:
            self.http_authproxy_endpoint = http_authproxy_endpoint
        if http_authproxy_tokenreview_endpoint is not None:
            self.http_authproxy_tokenreview_endpoint = http_authproxy_tokenreview_endpoint
        if http_authproxy_admin_groups is not None:
            self.http_authproxy_admin_groups = http_authproxy_admin_groups
        if http_authproxy_admin_usernames is not None:
            self.http_authproxy_admin_usernames = http_authproxy_admin_usernames
        if http_authproxy_verify_cert is not None:
            self.http_authproxy_verify_cert = http_authproxy_verify_cert
        if http_authproxy_skip_search is not None:
            self.http_authproxy_skip_search = http_authproxy_skip_search
        if http_authproxy_server_certificate is not None:
            self.http_authproxy_server_certificate = http_authproxy_server_certificate
        if oidc_name is not None:
            self.oidc_name = oidc_name
        if oidc_endpoint is not None:
            self.oidc_endpoint = oidc_endpoint
        if oidc_client_id is not None:
            self.oidc_client_id = oidc_client_id
        if oidc_client_secret is not None:
            self.oidc_client_secret = oidc_client_secret
        if oidc_groups_claim is not None:
            self.oidc_groups_claim = oidc_groups_claim
        if oidc_admin_group is not None:
            self.oidc_admin_group = oidc_admin_group
        if oidc_group_filter is not None:
            self.oidc_group_filter = oidc_group_filter
        if oidc_scope is not None:
            self.oidc_scope = oidc_scope
        if oidc_user_claim is not None:
            self.oidc_user_claim = oidc_user_claim
        if oidc_verify_cert is not None:
            self.oidc_verify_cert = oidc_verify_cert
        if oidc_auto_onboard is not None:
            self.oidc_auto_onboard = oidc_auto_onboard
        if oidc_extra_redirect_parms is not None:
            self.oidc_extra_redirect_parms = oidc_extra_redirect_parms
        if robot_token_duration is not None:
            self.robot_token_duration = robot_token_duration
        if robot_name_prefix is not None:
            self.robot_name_prefix = robot_name_prefix
        if notification_enable is not None:
            self.notification_enable = notification_enable
        if quota_per_project_enable is not None:
            self.quota_per_project_enable = quota_per_project_enable
        if storage_per_project is not None:
            self.storage_per_project = storage_per_project
        if audit_log_forward_endpoint is not None:
            self.audit_log_forward_endpoint = audit_log_forward_endpoint
        if skip_audit_log_database is not None:
            self.skip_audit_log_database = skip_audit_log_database
        if session_timeout is not None:
            self.session_timeout = session_timeout

    @property
    def auth_mode(self):
        """Gets the auth_mode of this Configurations.  # noqa: E501

        The auth mode of current system, such as \"db_auth\", \"ldap_auth\", \"oidc_auth\"  # noqa: E501

        :return: The auth_mode of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._auth_mode

    @auth_mode.setter
    def auth_mode(self, auth_mode):
        """Sets the auth_mode of this Configurations.

        The auth mode of current system, such as \"db_auth\", \"ldap_auth\", \"oidc_auth\"  # noqa: E501

        :param auth_mode: The auth_mode of this Configurations.  # noqa: E501
        :type: str
        """

        self._auth_mode = auth_mode

    @property
    def ldap_base_dn(self):
        """Gets the ldap_base_dn of this Configurations.  # noqa: E501

        The Base DN for LDAP binding.  # noqa: E501

        :return: The ldap_base_dn of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._ldap_base_dn

    @ldap_base_dn.setter
    def ldap_base_dn(self, ldap_base_dn):
        """Sets the ldap_base_dn of this Configurations.

        The Base DN for LDAP binding.  # noqa: E501

        :param ldap_base_dn: The ldap_base_dn of this Configurations.  # noqa: E501
        :type: str
        """

        self._ldap_base_dn = ldap_base_dn

    @property
    def ldap_filter(self):
        """Gets the ldap_filter of this Configurations.  # noqa: E501

        The filter for LDAP search  # noqa: E501

        :return: The ldap_filter of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._ldap_filter

    @ldap_filter.setter
    def ldap_filter(self, ldap_filter):
        """Sets the ldap_filter of this Configurations.

        The filter for LDAP search  # noqa: E501

        :param ldap_filter: The ldap_filter of this Configurations.  # noqa: E501
        :type: str
        """

        self._ldap_filter = ldap_filter

    @property
    def ldap_group_base_dn(self):
        """Gets the ldap_group_base_dn of this Configurations.  # noqa: E501

        The base DN to search LDAP group.  # noqa: E501

        :return: The ldap_group_base_dn of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._ldap_group_base_dn

    @ldap_group_base_dn.setter
    def ldap_group_base_dn(self, ldap_group_base_dn):
        """Sets the ldap_group_base_dn of this Configurations.

        The base DN to search LDAP group.  # noqa: E501

        :param ldap_group_base_dn: The ldap_group_base_dn of this Configurations.  # noqa: E501
        :type: str
        """

        self._ldap_group_base_dn = ldap_group_base_dn

    @property
    def ldap_group_admin_dn(self):
        """Gets the ldap_group_admin_dn of this Configurations.  # noqa: E501

        Specify the ldap group which have the same privilege with Harbor admin  # noqa: E501

        :return: The ldap_group_admin_dn of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._ldap_group_admin_dn

    @ldap_group_admin_dn.setter
    def ldap_group_admin_dn(self, ldap_group_admin_dn):
        """Sets the ldap_group_admin_dn of this Configurations.

        Specify the ldap group which have the same privilege with Harbor admin  # noqa: E501

        :param ldap_group_admin_dn: The ldap_group_admin_dn of this Configurations.  # noqa: E501
        :type: str
        """

        self._ldap_group_admin_dn = ldap_group_admin_dn

    @property
    def ldap_group_attribute_name(self):
        """Gets the ldap_group_attribute_name of this Configurations.  # noqa: E501

        The attribute which is used as identity of the LDAP group, default is cn.'  # noqa: E501

        :return: The ldap_group_attribute_name of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._ldap_group_attribute_name

    @ldap_group_attribute_name.setter
    def ldap_group_attribute_name(self, ldap_group_attribute_name):
        """Sets the ldap_group_attribute_name of this Configurations.

        The attribute which is used as identity of the LDAP group, default is cn.'  # noqa: E501

        :param ldap_group_attribute_name: The ldap_group_attribute_name of this Configurations.  # noqa: E501
        :type: str
        """

        self._ldap_group_attribute_name = ldap_group_attribute_name

    @property
    def ldap_group_search_filter(self):
        """Gets the ldap_group_search_filter of this Configurations.  # noqa: E501

        The filter to search the ldap group  # noqa: E501

        :return: The ldap_group_search_filter of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._ldap_group_search_filter

    @ldap_group_search_filter.setter
    def ldap_group_search_filter(self, ldap_group_search_filter):
        """Sets the ldap_group_search_filter of this Configurations.

        The filter to search the ldap group  # noqa: E501

        :param ldap_group_search_filter: The ldap_group_search_filter of this Configurations.  # noqa: E501
        :type: str
        """

        self._ldap_group_search_filter = ldap_group_search_filter

    @property
    def ldap_group_search_scope(self):
        """Gets the ldap_group_search_scope of this Configurations.  # noqa: E501

        The scope to search ldap group. ''0-LDAP_SCOPE_BASE, 1-LDAP_SCOPE_ONELEVEL, 2-LDAP_SCOPE_SUBTREE''  # noqa: E501

        :return: The ldap_group_search_scope of this Configurations.  # noqa: E501
        :rtype: int
        """
        return self._ldap_group_search_scope

    @ldap_group_search_scope.setter
    def ldap_group_search_scope(self, ldap_group_search_scope):
        """Sets the ldap_group_search_scope of this Configurations.

        The scope to search ldap group. ''0-LDAP_SCOPE_BASE, 1-LDAP_SCOPE_ONELEVEL, 2-LDAP_SCOPE_SUBTREE''  # noqa: E501

        :param ldap_group_search_scope: The ldap_group_search_scope of this Configurations.  # noqa: E501
        :type: int
        """

        self._ldap_group_search_scope = ldap_group_search_scope

    @property
    def ldap_scope(self):
        """Gets the ldap_scope of this Configurations.  # noqa: E501

        The scope to search ldap users,'0-LDAP_SCOPE_BASE, 1-LDAP_SCOPE_ONELEVEL, 2-LDAP_SCOPE_SUBTREE'  # noqa: E501

        :return: The ldap_scope of this Configurations.  # noqa: E501
        :rtype: int
        """
        return self._ldap_scope

    @ldap_scope.setter
    def ldap_scope(self, ldap_scope):
        """Sets the ldap_scope of this Configurations.

        The scope to search ldap users,'0-LDAP_SCOPE_BASE, 1-LDAP_SCOPE_ONELEVEL, 2-LDAP_SCOPE_SUBTREE'  # noqa: E501

        :param ldap_scope: The ldap_scope of this Configurations.  # noqa: E501
        :type: int
        """

        self._ldap_scope = ldap_scope

    @property
    def ldap_search_dn(self):
        """Gets the ldap_search_dn of this Configurations.  # noqa: E501

        The DN of the user to do the search.  # noqa: E501

        :return: The ldap_search_dn of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._ldap_search_dn

    @ldap_search_dn.setter
    def ldap_search_dn(self, ldap_search_dn):
        """Sets the ldap_search_dn of this Configurations.

        The DN of the user to do the search.  # noqa: E501

        :param ldap_search_dn: The ldap_search_dn of this Configurations.  # noqa: E501
        :type: str
        """

        self._ldap_search_dn = ldap_search_dn

    @property
    def ldap_search_password(self):
        """Gets the ldap_search_password of this Configurations.  # noqa: E501

        The password of the ldap search dn  # noqa: E501

        :return: The ldap_search_password of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._ldap_search_password

    @ldap_search_password.setter
    def ldap_search_password(self, ldap_search_password):
        """Sets the ldap_search_password of this Configurations.

        The password of the ldap search dn  # noqa: E501

        :param ldap_search_password: The ldap_search_password of this Configurations.  # noqa: E501
        :type: str
        """

        self._ldap_search_password = ldap_search_password

    @property
    def ldap_timeout(self):
        """Gets the ldap_timeout of this Configurations.  # noqa: E501

        Timeout in seconds for connection to LDAP server  # noqa: E501

        :return: The ldap_timeout of this Configurations.  # noqa: E501
        :rtype: int
        """
        return self._ldap_timeout

    @ldap_timeout.setter
    def ldap_timeout(self, ldap_timeout):
        """Sets the ldap_timeout of this Configurations.

        Timeout in seconds for connection to LDAP server  # noqa: E501

        :param ldap_timeout: The ldap_timeout of this Configurations.  # noqa: E501
        :type: int
        """

        self._ldap_timeout = ldap_timeout

    @property
    def ldap_uid(self):
        """Gets the ldap_uid of this Configurations.  # noqa: E501

        The attribute which is used as identity for the LDAP binding, such as \"CN\" or \"SAMAccountname\"  # noqa: E501

        :return: The ldap_uid of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._ldap_uid

    @ldap_uid.setter
    def ldap_uid(self, ldap_uid):
        """Sets the ldap_uid of this Configurations.

        The attribute which is used as identity for the LDAP binding, such as \"CN\" or \"SAMAccountname\"  # noqa: E501

        :param ldap_uid: The ldap_uid of this Configurations.  # noqa: E501
        :type: str
        """

        self._ldap_uid = ldap_uid

    @property
    def ldap_url(self):
        """Gets the ldap_url of this Configurations.  # noqa: E501

        The URL of LDAP server  # noqa: E501

        :return: The ldap_url of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._ldap_url

    @ldap_url.setter
    def ldap_url(self, ldap_url):
        """Sets the ldap_url of this Configurations.

        The URL of LDAP server  # noqa: E501

        :param ldap_url: The ldap_url of this Configurations.  # noqa: E501
        :type: str
        """

        self._ldap_url = ldap_url

    @property
    def ldap_verify_cert(self):
        """Gets the ldap_verify_cert of this Configurations.  # noqa: E501

        Whether verify your OIDC server certificate, disable it if your OIDC server is hosted via self-hosted certificate.  # noqa: E501

        :return: The ldap_verify_cert of this Configurations.  # noqa: E501
        :rtype: bool
        """
        return self._ldap_verify_cert

    @ldap_verify_cert.setter
    def ldap_verify_cert(self, ldap_verify_cert):
        """Sets the ldap_verify_cert of this Configurations.

        Whether verify your OIDC server certificate, disable it if your OIDC server is hosted via self-hosted certificate.  # noqa: E501

        :param ldap_verify_cert: The ldap_verify_cert of this Configurations.  # noqa: E501
        :type: bool
        """

        self._ldap_verify_cert = ldap_verify_cert

    @property
    def ldap_group_membership_attribute(self):
        """Gets the ldap_group_membership_attribute of this Configurations.  # noqa: E501

        The user attribute to identify the group membership  # noqa: E501

        :return: The ldap_group_membership_attribute of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._ldap_group_membership_attribute

    @ldap_group_membership_attribute.setter
    def ldap_group_membership_attribute(self, ldap_group_membership_attribute):
        """Sets the ldap_group_membership_attribute of this Configurations.

        The user attribute to identify the group membership  # noqa: E501

        :param ldap_group_membership_attribute: The ldap_group_membership_attribute of this Configurations.  # noqa: E501
        :type: str
        """

        self._ldap_group_membership_attribute = ldap_group_membership_attribute

    @property
    def project_creation_restriction(self):
        """Gets the project_creation_restriction of this Configurations.  # noqa: E501

        Indicate who can create projects, it could be ''adminonly'' or ''everyone''.  # noqa: E501

        :return: The project_creation_restriction of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._project_creation_restriction

    @project_creation_restriction.setter
    def project_creation_restriction(self, project_creation_restriction):
        """Sets the project_creation_restriction of this Configurations.

        Indicate who can create projects, it could be ''adminonly'' or ''everyone''.  # noqa: E501

        :param project_creation_restriction: The project_creation_restriction of this Configurations.  # noqa: E501
        :type: str
        """

        self._project_creation_restriction = project_creation_restriction

    @property
    def read_only(self):
        """Gets the read_only of this Configurations.  # noqa: E501

        The flag to indicate whether Harbor is in readonly mode.  # noqa: E501

        :return: The read_only of this Configurations.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this Configurations.

        The flag to indicate whether Harbor is in readonly mode.  # noqa: E501

        :param read_only: The read_only of this Configurations.  # noqa: E501
        :type: bool
        """

        self._read_only = read_only

    @property
    def self_registration(self):
        """Gets the self_registration of this Configurations.  # noqa: E501

        Whether the Harbor instance supports self-registration.  If it''s set to false, admin need to add user to the instance.  # noqa: E501

        :return: The self_registration of this Configurations.  # noqa: E501
        :rtype: bool
        """
        return self._self_registration

    @self_registration.setter
    def self_registration(self, self_registration):
        """Sets the self_registration of this Configurations.

        Whether the Harbor instance supports self-registration.  If it''s set to false, admin need to add user to the instance.  # noqa: E501

        :param self_registration: The self_registration of this Configurations.  # noqa: E501
        :type: bool
        """

        self._self_registration = self_registration

    @property
    def token_expiration(self):
        """Gets the token_expiration of this Configurations.  # noqa: E501

        The expiration time of the token for internal Registry, in minutes.  # noqa: E501

        :return: The token_expiration of this Configurations.  # noqa: E501
        :rtype: int
        """
        return self._token_expiration

    @token_expiration.setter
    def token_expiration(self, token_expiration):
        """Sets the token_expiration of this Configurations.

        The expiration time of the token for internal Registry, in minutes.  # noqa: E501

        :param token_expiration: The token_expiration of this Configurations.  # noqa: E501
        :type: int
        """

        self._token_expiration = token_expiration

    @property
    def uaa_client_id(self):
        """Gets the uaa_client_id of this Configurations.  # noqa: E501

        The client id of UAA  # noqa: E501

        :return: The uaa_client_id of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._uaa_client_id

    @uaa_client_id.setter
    def uaa_client_id(self, uaa_client_id):
        """Sets the uaa_client_id of this Configurations.

        The client id of UAA  # noqa: E501

        :param uaa_client_id: The uaa_client_id of this Configurations.  # noqa: E501
        :type: str
        """

        self._uaa_client_id = uaa_client_id

    @property
    def uaa_client_secret(self):
        """Gets the uaa_client_secret of this Configurations.  # noqa: E501

        The client secret of the UAA  # noqa: E501

        :return: The uaa_client_secret of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._uaa_client_secret

    @uaa_client_secret.setter
    def uaa_client_secret(self, uaa_client_secret):
        """Sets the uaa_client_secret of this Configurations.

        The client secret of the UAA  # noqa: E501

        :param uaa_client_secret: The uaa_client_secret of this Configurations.  # noqa: E501
        :type: str
        """

        self._uaa_client_secret = uaa_client_secret

    @property
    def uaa_endpoint(self):
        """Gets the uaa_endpoint of this Configurations.  # noqa: E501

        The endpoint of the UAA  # noqa: E501

        :return: The uaa_endpoint of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._uaa_endpoint

    @uaa_endpoint.setter
    def uaa_endpoint(self, uaa_endpoint):
        """Sets the uaa_endpoint of this Configurations.

        The endpoint of the UAA  # noqa: E501

        :param uaa_endpoint: The uaa_endpoint of this Configurations.  # noqa: E501
        :type: str
        """

        self._uaa_endpoint = uaa_endpoint

    @property
    def uaa_verify_cert(self):
        """Gets the uaa_verify_cert of this Configurations.  # noqa: E501

        Verify the certificate in UAA server  # noqa: E501

        :return: The uaa_verify_cert of this Configurations.  # noqa: E501
        :rtype: bool
        """
        return self._uaa_verify_cert

    @uaa_verify_cert.setter
    def uaa_verify_cert(self, uaa_verify_cert):
        """Sets the uaa_verify_cert of this Configurations.

        Verify the certificate in UAA server  # noqa: E501

        :param uaa_verify_cert: The uaa_verify_cert of this Configurations.  # noqa: E501
        :type: bool
        """

        self._uaa_verify_cert = uaa_verify_cert

    @property
    def http_authproxy_endpoint(self):
        """Gets the http_authproxy_endpoint of this Configurations.  # noqa: E501

        The endpoint of the HTTP auth  # noqa: E501

        :return: The http_authproxy_endpoint of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._http_authproxy_endpoint

    @http_authproxy_endpoint.setter
    def http_authproxy_endpoint(self, http_authproxy_endpoint):
        """Sets the http_authproxy_endpoint of this Configurations.

        The endpoint of the HTTP auth  # noqa: E501

        :param http_authproxy_endpoint: The http_authproxy_endpoint of this Configurations.  # noqa: E501
        :type: str
        """

        self._http_authproxy_endpoint = http_authproxy_endpoint

    @property
    def http_authproxy_tokenreview_endpoint(self):
        """Gets the http_authproxy_tokenreview_endpoint of this Configurations.  # noqa: E501

        The token review endpoint  # noqa: E501

        :return: The http_authproxy_tokenreview_endpoint of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._http_authproxy_tokenreview_endpoint

    @http_authproxy_tokenreview_endpoint.setter
    def http_authproxy_tokenreview_endpoint(self, http_authproxy_tokenreview_endpoint):
        """Sets the http_authproxy_tokenreview_endpoint of this Configurations.

        The token review endpoint  # noqa: E501

        :param http_authproxy_tokenreview_endpoint: The http_authproxy_tokenreview_endpoint of this Configurations.  # noqa: E501
        :type: str
        """

        self._http_authproxy_tokenreview_endpoint = http_authproxy_tokenreview_endpoint

    @property
    def http_authproxy_admin_groups(self):
        """Gets the http_authproxy_admin_groups of this Configurations.  # noqa: E501

        The group which has the harbor admin privileges  # noqa: E501

        :return: The http_authproxy_admin_groups of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._http_authproxy_admin_groups

    @http_authproxy_admin_groups.setter
    def http_authproxy_admin_groups(self, http_authproxy_admin_groups):
        """Sets the http_authproxy_admin_groups of this Configurations.

        The group which has the harbor admin privileges  # noqa: E501

        :param http_authproxy_admin_groups: The http_authproxy_admin_groups of this Configurations.  # noqa: E501
        :type: str
        """

        self._http_authproxy_admin_groups = http_authproxy_admin_groups

    @property
    def http_authproxy_admin_usernames(self):
        """Gets the http_authproxy_admin_usernames of this Configurations.  # noqa: E501

        The username which has the harbor admin privileges  # noqa: E501

        :return: The http_authproxy_admin_usernames of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._http_authproxy_admin_usernames

    @http_authproxy_admin_usernames.setter
    def http_authproxy_admin_usernames(self, http_authproxy_admin_usernames):
        """Sets the http_authproxy_admin_usernames of this Configurations.

        The username which has the harbor admin privileges  # noqa: E501

        :param http_authproxy_admin_usernames: The http_authproxy_admin_usernames of this Configurations.  # noqa: E501
        :type: str
        """

        self._http_authproxy_admin_usernames = http_authproxy_admin_usernames

    @property
    def http_authproxy_verify_cert(self):
        """Gets the http_authproxy_verify_cert of this Configurations.  # noqa: E501

        Verify the HTTP auth provider's certificate  # noqa: E501

        :return: The http_authproxy_verify_cert of this Configurations.  # noqa: E501
        :rtype: bool
        """
        return self._http_authproxy_verify_cert

    @http_authproxy_verify_cert.setter
    def http_authproxy_verify_cert(self, http_authproxy_verify_cert):
        """Sets the http_authproxy_verify_cert of this Configurations.

        Verify the HTTP auth provider's certificate  # noqa: E501

        :param http_authproxy_verify_cert: The http_authproxy_verify_cert of this Configurations.  # noqa: E501
        :type: bool
        """

        self._http_authproxy_verify_cert = http_authproxy_verify_cert

    @property
    def http_authproxy_skip_search(self):
        """Gets the http_authproxy_skip_search of this Configurations.  # noqa: E501

        Search user before onboard  # noqa: E501

        :return: The http_authproxy_skip_search of this Configurations.  # noqa: E501
        :rtype: bool
        """
        return self._http_authproxy_skip_search

    @http_authproxy_skip_search.setter
    def http_authproxy_skip_search(self, http_authproxy_skip_search):
        """Sets the http_authproxy_skip_search of this Configurations.

        Search user before onboard  # noqa: E501

        :param http_authproxy_skip_search: The http_authproxy_skip_search of this Configurations.  # noqa: E501
        :type: bool
        """

        self._http_authproxy_skip_search = http_authproxy_skip_search

    @property
    def http_authproxy_server_certificate(self):
        """Gets the http_authproxy_server_certificate of this Configurations.  # noqa: E501

        The certificate of the HTTP auth provider  # noqa: E501

        :return: The http_authproxy_server_certificate of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._http_authproxy_server_certificate

    @http_authproxy_server_certificate.setter
    def http_authproxy_server_certificate(self, http_authproxy_server_certificate):
        """Sets the http_authproxy_server_certificate of this Configurations.

        The certificate of the HTTP auth provider  # noqa: E501

        :param http_authproxy_server_certificate: The http_authproxy_server_certificate of this Configurations.  # noqa: E501
        :type: str
        """

        self._http_authproxy_server_certificate = http_authproxy_server_certificate

    @property
    def oidc_name(self):
        """Gets the oidc_name of this Configurations.  # noqa: E501

        The OIDC provider name  # noqa: E501

        :return: The oidc_name of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._oidc_name

    @oidc_name.setter
    def oidc_name(self, oidc_name):
        """Sets the oidc_name of this Configurations.

        The OIDC provider name  # noqa: E501

        :param oidc_name: The oidc_name of this Configurations.  # noqa: E501
        :type: str
        """

        self._oidc_name = oidc_name

    @property
    def oidc_endpoint(self):
        """Gets the oidc_endpoint of this Configurations.  # noqa: E501

        The endpoint of the OIDC provider  # noqa: E501

        :return: The oidc_endpoint of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._oidc_endpoint

    @oidc_endpoint.setter
    def oidc_endpoint(self, oidc_endpoint):
        """Sets the oidc_endpoint of this Configurations.

        The endpoint of the OIDC provider  # noqa: E501

        :param oidc_endpoint: The oidc_endpoint of this Configurations.  # noqa: E501
        :type: str
        """

        self._oidc_endpoint = oidc_endpoint

    @property
    def oidc_client_id(self):
        """Gets the oidc_client_id of this Configurations.  # noqa: E501

        The client ID of the OIDC provider  # noqa: E501

        :return: The oidc_client_id of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._oidc_client_id

    @oidc_client_id.setter
    def oidc_client_id(self, oidc_client_id):
        """Sets the oidc_client_id of this Configurations.

        The client ID of the OIDC provider  # noqa: E501

        :param oidc_client_id: The oidc_client_id of this Configurations.  # noqa: E501
        :type: str
        """

        self._oidc_client_id = oidc_client_id

    @property
    def oidc_client_secret(self):
        """Gets the oidc_client_secret of this Configurations.  # noqa: E501

        The OIDC provider secret  # noqa: E501

        :return: The oidc_client_secret of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._oidc_client_secret

    @oidc_client_secret.setter
    def oidc_client_secret(self, oidc_client_secret):
        """Sets the oidc_client_secret of this Configurations.

        The OIDC provider secret  # noqa: E501

        :param oidc_client_secret: The oidc_client_secret of this Configurations.  # noqa: E501
        :type: str
        """

        self._oidc_client_secret = oidc_client_secret

    @property
    def oidc_groups_claim(self):
        """Gets the oidc_groups_claim of this Configurations.  # noqa: E501

        The attribute claims the group name  # noqa: E501

        :return: The oidc_groups_claim of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._oidc_groups_claim

    @oidc_groups_claim.setter
    def oidc_groups_claim(self, oidc_groups_claim):
        """Sets the oidc_groups_claim of this Configurations.

        The attribute claims the group name  # noqa: E501

        :param oidc_groups_claim: The oidc_groups_claim of this Configurations.  # noqa: E501
        :type: str
        """

        self._oidc_groups_claim = oidc_groups_claim

    @property
    def oidc_admin_group(self):
        """Gets the oidc_admin_group of this Configurations.  # noqa: E501

        The OIDC group which has the harbor admin privileges  # noqa: E501

        :return: The oidc_admin_group of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._oidc_admin_group

    @oidc_admin_group.setter
    def oidc_admin_group(self, oidc_admin_group):
        """Sets the oidc_admin_group of this Configurations.

        The OIDC group which has the harbor admin privileges  # noqa: E501

        :param oidc_admin_group: The oidc_admin_group of this Configurations.  # noqa: E501
        :type: str
        """

        self._oidc_admin_group = oidc_admin_group

    @property
    def oidc_group_filter(self):
        """Gets the oidc_group_filter of this Configurations.  # noqa: E501

        The OIDC group filter which filters out the group name doesn't match the regular expression  # noqa: E501

        :return: The oidc_group_filter of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._oidc_group_filter

    @oidc_group_filter.setter
    def oidc_group_filter(self, oidc_group_filter):
        """Sets the oidc_group_filter of this Configurations.

        The OIDC group filter which filters out the group name doesn't match the regular expression  # noqa: E501

        :param oidc_group_filter: The oidc_group_filter of this Configurations.  # noqa: E501
        :type: str
        """

        self._oidc_group_filter = oidc_group_filter

    @property
    def oidc_scope(self):
        """Gets the oidc_scope of this Configurations.  # noqa: E501

        The scope of the OIDC provider  # noqa: E501

        :return: The oidc_scope of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._oidc_scope

    @oidc_scope.setter
    def oidc_scope(self, oidc_scope):
        """Sets the oidc_scope of this Configurations.

        The scope of the OIDC provider  # noqa: E501

        :param oidc_scope: The oidc_scope of this Configurations.  # noqa: E501
        :type: str
        """

        self._oidc_scope = oidc_scope

    @property
    def oidc_user_claim(self):
        """Gets the oidc_user_claim of this Configurations.  # noqa: E501

        The attribute claims the username  # noqa: E501

        :return: The oidc_user_claim of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._oidc_user_claim

    @oidc_user_claim.setter
    def oidc_user_claim(self, oidc_user_claim):
        """Sets the oidc_user_claim of this Configurations.

        The attribute claims the username  # noqa: E501

        :param oidc_user_claim: The oidc_user_claim of this Configurations.  # noqa: E501
        :type: str
        """

        self._oidc_user_claim = oidc_user_claim

    @property
    def oidc_verify_cert(self):
        """Gets the oidc_verify_cert of this Configurations.  # noqa: E501

        Verify the OIDC provider's certificate'  # noqa: E501

        :return: The oidc_verify_cert of this Configurations.  # noqa: E501
        :rtype: bool
        """
        return self._oidc_verify_cert

    @oidc_verify_cert.setter
    def oidc_verify_cert(self, oidc_verify_cert):
        """Sets the oidc_verify_cert of this Configurations.

        Verify the OIDC provider's certificate'  # noqa: E501

        :param oidc_verify_cert: The oidc_verify_cert of this Configurations.  # noqa: E501
        :type: bool
        """

        self._oidc_verify_cert = oidc_verify_cert

    @property
    def oidc_auto_onboard(self):
        """Gets the oidc_auto_onboard of this Configurations.  # noqa: E501

        Auto onboard the OIDC user  # noqa: E501

        :return: The oidc_auto_onboard of this Configurations.  # noqa: E501
        :rtype: bool
        """
        return self._oidc_auto_onboard

    @oidc_auto_onboard.setter
    def oidc_auto_onboard(self, oidc_auto_onboard):
        """Sets the oidc_auto_onboard of this Configurations.

        Auto onboard the OIDC user  # noqa: E501

        :param oidc_auto_onboard: The oidc_auto_onboard of this Configurations.  # noqa: E501
        :type: bool
        """

        self._oidc_auto_onboard = oidc_auto_onboard

    @property
    def oidc_extra_redirect_parms(self):
        """Gets the oidc_extra_redirect_parms of this Configurations.  # noqa: E501

        Extra parameters to add when redirect request to OIDC provider  # noqa: E501

        :return: The oidc_extra_redirect_parms of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._oidc_extra_redirect_parms

    @oidc_extra_redirect_parms.setter
    def oidc_extra_redirect_parms(self, oidc_extra_redirect_parms):
        """Sets the oidc_extra_redirect_parms of this Configurations.

        Extra parameters to add when redirect request to OIDC provider  # noqa: E501

        :param oidc_extra_redirect_parms: The oidc_extra_redirect_parms of this Configurations.  # noqa: E501
        :type: str
        """

        self._oidc_extra_redirect_parms = oidc_extra_redirect_parms

    @property
    def robot_token_duration(self):
        """Gets the robot_token_duration of this Configurations.  # noqa: E501

        The robot account token duration in days  # noqa: E501

        :return: The robot_token_duration of this Configurations.  # noqa: E501
        :rtype: int
        """
        return self._robot_token_duration

    @robot_token_duration.setter
    def robot_token_duration(self, robot_token_duration):
        """Sets the robot_token_duration of this Configurations.

        The robot account token duration in days  # noqa: E501

        :param robot_token_duration: The robot_token_duration of this Configurations.  # noqa: E501
        :type: int
        """

        self._robot_token_duration = robot_token_duration

    @property
    def robot_name_prefix(self):
        """Gets the robot_name_prefix of this Configurations.  # noqa: E501

        The rebot account name prefix  # noqa: E501

        :return: The robot_name_prefix of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._robot_name_prefix

    @robot_name_prefix.setter
    def robot_name_prefix(self, robot_name_prefix):
        """Sets the robot_name_prefix of this Configurations.

        The rebot account name prefix  # noqa: E501

        :param robot_name_prefix: The robot_name_prefix of this Configurations.  # noqa: E501
        :type: str
        """

        self._robot_name_prefix = robot_name_prefix

    @property
    def notification_enable(self):
        """Gets the notification_enable of this Configurations.  # noqa: E501

        Enable notification  # noqa: E501

        :return: The notification_enable of this Configurations.  # noqa: E501
        :rtype: bool
        """
        return self._notification_enable

    @notification_enable.setter
    def notification_enable(self, notification_enable):
        """Sets the notification_enable of this Configurations.

        Enable notification  # noqa: E501

        :param notification_enable: The notification_enable of this Configurations.  # noqa: E501
        :type: bool
        """

        self._notification_enable = notification_enable

    @property
    def quota_per_project_enable(self):
        """Gets the quota_per_project_enable of this Configurations.  # noqa: E501

        Enable quota per project  # noqa: E501

        :return: The quota_per_project_enable of this Configurations.  # noqa: E501
        :rtype: bool
        """
        return self._quota_per_project_enable

    @quota_per_project_enable.setter
    def quota_per_project_enable(self, quota_per_project_enable):
        """Sets the quota_per_project_enable of this Configurations.

        Enable quota per project  # noqa: E501

        :param quota_per_project_enable: The quota_per_project_enable of this Configurations.  # noqa: E501
        :type: bool
        """

        self._quota_per_project_enable = quota_per_project_enable

    @property
    def storage_per_project(self):
        """Gets the storage_per_project of this Configurations.  # noqa: E501

        The storage quota per project  # noqa: E501

        :return: The storage_per_project of this Configurations.  # noqa: E501
        :rtype: int
        """
        return self._storage_per_project

    @storage_per_project.setter
    def storage_per_project(self, storage_per_project):
        """Sets the storage_per_project of this Configurations.

        The storage quota per project  # noqa: E501

        :param storage_per_project: The storage_per_project of this Configurations.  # noqa: E501
        :type: int
        """

        self._storage_per_project = storage_per_project

    @property
    def audit_log_forward_endpoint(self):
        """Gets the audit_log_forward_endpoint of this Configurations.  # noqa: E501

        The audit log forward endpoint  # noqa: E501

        :return: The audit_log_forward_endpoint of this Configurations.  # noqa: E501
        :rtype: str
        """
        return self._audit_log_forward_endpoint

    @audit_log_forward_endpoint.setter
    def audit_log_forward_endpoint(self, audit_log_forward_endpoint):
        """Sets the audit_log_forward_endpoint of this Configurations.

        The audit log forward endpoint  # noqa: E501

        :param audit_log_forward_endpoint: The audit_log_forward_endpoint of this Configurations.  # noqa: E501
        :type: str
        """

        self._audit_log_forward_endpoint = audit_log_forward_endpoint

    @property
    def skip_audit_log_database(self):
        """Gets the skip_audit_log_database of this Configurations.  # noqa: E501

        Skip audit log database  # noqa: E501

        :return: The skip_audit_log_database of this Configurations.  # noqa: E501
        :rtype: bool
        """
        return self._skip_audit_log_database

    @skip_audit_log_database.setter
    def skip_audit_log_database(self, skip_audit_log_database):
        """Sets the skip_audit_log_database of this Configurations.

        Skip audit log database  # noqa: E501

        :param skip_audit_log_database: The skip_audit_log_database of this Configurations.  # noqa: E501
        :type: bool
        """

        self._skip_audit_log_database = skip_audit_log_database

    @property
    def session_timeout(self):
        """Gets the session_timeout of this Configurations.  # noqa: E501

        The session timeout for harbor, in minutes.  # noqa: E501

        :return: The session_timeout of this Configurations.  # noqa: E501
        :rtype: int
        """
        return self._session_timeout

    @session_timeout.setter
    def session_timeout(self, session_timeout):
        """Sets the session_timeout of this Configurations.

        The session timeout for harbor, in minutes.  # noqa: E501

        :param session_timeout: The session_timeout of this Configurations.  # noqa: E501
        :type: int
        """

        self._session_timeout = session_timeout

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Configurations, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Configurations):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Configurations):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Statistic(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'private_project_count': 'int',
        'private_repo_count': 'int',
        'public_project_count': 'int',
        'public_repo_count': 'int',
        'total_project_count': 'int',
        'total_repo_count': 'int',
        'total_storage_consumption': 'int'
    }

    attribute_map = {
        'private_project_count': 'private_project_count',
        'private_repo_count': 'private_repo_count',
        'public_project_count': 'public_project_count',
        'public_repo_count': 'public_repo_count',
        'total_project_count': 'total_project_count',
        'total_repo_count': 'total_repo_count',
        'total_storage_consumption': 'total_storage_consumption'
    }

    def __init__(self, private_project_count=None, private_repo_count=None, public_project_count=None, public_repo_count=None, total_project_count=None, total_repo_count=None, total_storage_consumption=None, _configuration=None):  # noqa: E501
        """Statistic - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._private_project_count = None
        self._private_repo_count = None
        self._public_project_count = None
        self._public_repo_count = None
        self._total_project_count = None
        self._total_repo_count = None
        self._total_storage_consumption = None
        self.discriminator = None

        if private_project_count is not None:
            self.private_project_count = private_project_count
        if private_repo_count is not None:
            self.private_repo_count = private_repo_count
        if public_project_count is not None:
            self.public_project_count = public_project_count
        if public_repo_count is not None:
            self.public_repo_count = public_repo_count
        if total_project_count is not None:
            self.total_project_count = total_project_count
        if total_repo_count is not None:
            self.total_repo_count = total_repo_count
        if total_storage_consumption is not None:
            self.total_storage_consumption = total_storage_consumption

    @property
    def private_project_count(self):
        """Gets the private_project_count of this Statistic.  # noqa: E501

        The count of the private projects  # noqa: E501

        :return: The private_project_count of this Statistic.  # noqa: E501
        :rtype: int
        """
        return self._private_project_count

    @private_project_count.setter
    def private_project_count(self, private_project_count):
        """Sets the private_project_count of this Statistic.

        The count of the private projects  # noqa: E501

        :param private_project_count: The private_project_count of this Statistic.  # noqa: E501
        :type: int
        """

        self._private_project_count = private_project_count

    @property
    def private_repo_count(self):
        """Gets the private_repo_count of this Statistic.  # noqa: E501

        The count of the private repositories  # noqa: E501

        :return: The private_repo_count of this Statistic.  # noqa: E501
        :rtype: int
        """
        return self._private_repo_count

    @private_repo_count.setter
    def private_repo_count(self, private_repo_count):
        """Sets the private_repo_count of this Statistic.

        The count of the private repositories  # noqa: E501

        :param private_repo_count: The private_repo_count of this Statistic.  # noqa: E501
        :type: int
        """

        self._private_repo_count = private_repo_count

    @property
    def public_project_count(self):
        """Gets the public_project_count of this Statistic.  # noqa: E501

        The count of the public projects  # noqa: E501

        :return: The public_project_count of this Statistic.  # noqa: E501
        :rtype: int
        """
        return self._public_project_count

    @public_project_count.setter
    def public_project_count(self, public_project_count):
        """Sets the public_project_count of this Statistic.

        The count of the public projects  # noqa: E501

        :param public_project_count: The public_project_count of this Statistic.  # noqa: E501
        :type: int
        """

        self._public_project_count = public_project_count

    @property
    def public_repo_count(self):
        """Gets the public_repo_count of this Statistic.  # noqa: E501

        The count of the public repositories  # noqa: E501

        :return: The public_repo_count of this Statistic.  # noqa: E501
        :rtype: int
        """
        return self._public_repo_count

    @public_repo_count.setter
    def public_repo_count(self, public_repo_count):
        """Sets the public_repo_count of this Statistic.

        The count of the public repositories  # noqa: E501

        :param public_repo_count: The public_repo_count of this Statistic.  # noqa: E501
        :type: int
        """

        self._public_repo_count = public_repo_count

    @property
    def total_project_count(self):
        """Gets the total_project_count of this Statistic.  # noqa: E501

        The count of the total projects, only be seen by the system admin  # noqa: E501

        :return: The total_project_count of this Statistic.  # noqa: E501
        :rtype: int
        """
        return self._total_project_count

    @total_project_count.setter
    def total_project_count(self, total_project_count):
        """Sets the total_project_count of this Statistic.

        The count of the total projects, only be seen by the system admin  # noqa: E501

        :param total_project_count: The total_project_count of this Statistic.  # noqa: E501
        :type: int
        """

        self._total_project_count = total_project_count

    @property
    def total_repo_count(self):
        """Gets the total_repo_count of this Statistic.  # noqa: E501

        The count of the total repositories, only be seen by the system admin  # noqa: E501

        :return: The total_repo_count of this Statistic.  # noqa: E501
        :rtype: int
        """
        return self._total_repo_count

    @total_repo_count.setter
    def total_repo_count(self, total_repo_count):
        """Sets the total_repo_count of this Statistic.

        The count of the total repositories, only be seen by the system admin  # noqa: E501

        :param total_repo_count: The total_repo_count of this Statistic.  # noqa: E501
        :type: int
        """

        self._total_repo_count = total_repo_count

    @property
    def total_storage_consumption(self):
        """Gets the total_storage_consumption of this Statistic.  # noqa: E501

        The total storage consumption of blobs, only be seen by the system admin  # noqa: E501

        :return: The total_storage_consumption of this Statistic.  # noqa: E501
        :rtype: int
        """
        return self._total_storage_consumption

    @total_storage_consumption.setter
    def total_storage_consumption(self, total_storage_consumption):
        """Sets the total_storage_consumption of this Statistic.

        The total storage consumption of blobs, only be seen by the system admin  # noqa: E501

        :param total_storage_consumption: The total_storage_consumption of this Statistic.  # noqa: E501
        :type: int
        """

        self._total_storage_consumption = total_storage_consumption

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Statistic, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Statistic):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Statistic):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from harbor_client.api.ldap_api import LdapApi
from harbor_client.api.retention_api import RetentionApi
from harbor_client.api.system_cve_allowlist_api import SystemCVEAllowlistApi
from harbor_client.api.artifact_api import ArtifactApi
from harbor_client.api.auditlog_api import AuditlogApi
from harbor_client.api.configure_api import ConfigureApi
from harbor_client.api.gc_api import GcApi
from harbor_client.api.health_api import HealthApi
from harbor_client.api.icon_api import IconApi
from harbor_client.api.immutable_api import ImmutableApi
from harbor_client.api.jobservice_api import JobserviceApi
from harbor_client.api.label_api import LabelApi
from harbor_client.api.member_api import MemberApi
from harbor_client.api.oidc_api import OidcApi
from harbor_client.api.ping_api import PingApi
from harbor_client.api.preheat_api import PreheatApi
from harbor_client.api.project_api import ProjectApi
from harbor_client.api.project_metadata_api import ProjectMetadataApi
from harbor_client.api.purge_api import PurgeApi
from harbor_client.api.quota_api import QuotaApi
from harbor_client.api.registry_api import RegistryApi
from harbor_client.api.replication_api import ReplicationApi
from harbor_client.api.repository_api import RepositoryApi
from harbor_client.api.robot_api import RobotApi
from harbor_client.api.robotv1_api import Robotv1Api
from harbor_client.api.scan_api import ScanApi
from harbor_client.api.scan_all_api import ScanAllApi
from harbor_client.api.scan_data_export_api import ScanDataExportApi
from harbor_client.api.scanner_api import ScannerApi
from harbor_client.api.schedule_api import ScheduleApi
from harbor_client.api.search_api import SearchApi
from harbor_client.api.statistic_api import StatisticApi
from harbor_client.api.systeminfo_api import SysteminfoApi
from harbor_client.api.user_api import UserApi
from harbor_client.api.usergroup_api import UsergroupApi
from harbor_client.api.webhook_api import WebhookApi
from harbor_client.api.webhookjob_api import WebhookjobApi

# import ApiClient
from harbor_client.api_client import ApiClient
from harbor_client.configuration import Configuration
# import models into sdk package
from harbor_client.models.access import Access
from harbor_client.models.accessory import Accessory
from harbor_client.models.action_request import ActionRequest
from harbor_client.models.addition_link import AdditionLink
from harbor_client.models.addition_links import AdditionLinks
from harbor_client.models.annotations import Annotations
from harbor_client.models.artifact import Artifact
from harbor_client.models.audit_log import AuditLog
from harbor_client.models.authproxy_setting import AuthproxySetting
from harbor_client.models.body import Body
from harbor_client.models.body1 import Body1
from harbor_client.models.bool_config_item import BoolConfigItem
from harbor_client.models.cve_allowlist import CVEAllowlist
from harbor_client.models.cve_allowlist_item import CVEAllowlistItem
from harbor_client.models.chart_metadata import ChartMetadata
from harbor_client.models.chart_version import ChartVersion
from harbor_client.models.component_health_status import ComponentHealthStatus
from harbor_client.models.configurations import Configurations
from harbor_client.models.configurations_response import ConfigurationsResponse
from harbor_client.models.configurations_response_scan_all_policy import ConfigurationsResponseScanAllPolicy
from harbor_client.models.configurations_response_scan_all_policy_parameter import ConfigurationsResponseScanAllPolicyParameter
from harbor_client.models.endpoint import Endpoint
from harbor_client.models.error import Error
from harbor_client.models.errors import Errors
from harbor_client.models.event_type import EventType
from harbor_client.models.exec_history import ExecHistory
from harbor_client.models.execution import Execution
from harbor_client.models.extra_attrs import ExtraAttrs
from harbor_client.models.filter_style import FilterStyle
from harbor_client.models.gc_history import GCHistory
from harbor_client.models.general_info import GeneralInfo
from harbor_client.models.icon import Icon
from harbor_client.models.immutable_rule import ImmutableRule
from harbor_client.models.immutable_selector import ImmutableSelector
from harbor_client.models.instance import Instance
from harbor_client.models.integer_config_item import IntegerConfigItem
from harbor_client.models.internal_configuration_value import InternalConfigurationValue
from harbor_client.models.internal_configurations_response import InternalConfigurationsResponse
from harbor_client.models.is_default import IsDefault
from harbor_client.models.job_queue import JobQueue
from harbor_client.models.label import Label
from harbor_client.models.ldap_conf import LdapConf
from harbor_client.models.ldap_failed_import_user import LdapFailedImportUser
from harbor_client.models.ldap_import_users import LdapImportUsers
from harbor_client.models.ldap_ping_result import LdapPingResult
from harbor_client.models.ldap_user import LdapUser
from harbor_client.models.metadata import Metadata
from harbor_client.models.metrics import Metrics
from harbor_client.models.native_report_summary import NativeReportSummary
from harbor_client.models.notify_type import NotifyType
from harbor_client.models.oidc_cli_secret_req import OIDCCliSecretReq
from harbor_client.models.oidc_user_info import OIDCUserInfo
from harbor_client.models.overall_health_status import OverallHealthStatus
from harbor_client.models.password_req import PasswordReq
from harbor_client.models.permission import Permission
from harbor_client.models.platform import Platform
from harbor_client.models.preheat_policy import PreheatPolicy
from harbor_client.models.project import Project
from harbor_client.models.project_deletable import ProjectDeletable
from harbor_client.models.project_member import ProjectMember
from harbor_client.models.project_member_entity import ProjectMemberEntity
from harbor_client.models.project_metadata import ProjectMetadata
from harbor_client.models.project_req import ProjectReq
from harbor_client.models.project_scanner import ProjectScanner
from harbor_client.models.project_summary import ProjectSummary
from harbor_client.models.project_summary_quota import ProjectSummaryQuota
from harbor_client.models.provider_under_project import ProviderUnderProject
from harbor_client.models.quota import Quota
from harbor_client.models.quota_ref_object import QuotaRefObject
from harbor_client.models.quota_update_req import QuotaUpdateReq
from harbor_client.models.reference import Reference
from harbor_client.models.registry import Registry
from harbor_client.models.registry_credential import RegistryCredential
from harbor_client.models.registry_endpoint import RegistryEndpoint
from harbor_client.models.registry_info import RegistryInfo
from harbor_client.models.registry_ping import RegistryPing
from harbor_client.models.registry_provider_credential_pattern import RegistryProviderCredentialPattern
from harbor_client.models.registry_provider_endpoint_pattern import RegistryProviderEndpointPattern
from harbor_client.models.registry_provider_info import RegistryProviderInfo
from harbor_client.models.registry_update import RegistryUpdate
from harbor_client.models.replication_execution import ReplicationExecution
from harbor_client.models.replication_filter import ReplicationFilter
from harbor_client.models.replication_policy import ReplicationPolicy
from harbor_client.models.replication_task import ReplicationTask
from harbor_client.models.replication_trigger import ReplicationTrigger
from harbor_client.models.replication_trigger_settings import ReplicationTriggerSettings
from harbor_client.models.repository import Repository
from harbor_client.models.resource_list import ResourceList
from harbor_client.models.retention_execution import RetentionExecution
from harbor_client.models.retention_execution_task import RetentionExecutionTask
from harbor_client.models.retention_metadata import RetentionMetadata
from harbor_client.models.retention_policy import RetentionPolicy
from harbor_client.models.retention_policy_scope import RetentionPolicyScope
from harbor_client.models.retention_rule import RetentionRule
from harbor_client.models.retention_rule_metadata import RetentionRuleMetadata
from harbor_client.models.retention_rule_param_metadata import RetentionRuleParamMetadata
from harbor_client.models.retention_rule_trigger import RetentionRuleTrigger
from harbor_client.models.retention_selector import RetentionSelector
from harbor_client.models.retention_selector_metadata import RetentionSelectorMetadata
from harbor_client.models.robot import Robot
from harbor_client.models.robot_create import RobotCreate
from harbor_client.models.robot_create_v1 import RobotCreateV1
from harbor_client.models.robot_created import RobotCreated
from harbor_client.models.robot_permission import RobotPermission
from harbor_client.models.robot_sec import RobotSec
from harbor_client.models.role_request import RoleRequest
from harbor_client.models.scan_data_export_execution import ScanDataExportExecution
from harbor_client.models.scan_data_export_execution_list import ScanDataExportExecutionList
from harbor_client.models.scan_data_export_job import ScanDataExportJob
from harbor_client.models.scan_data_export_request import ScanDataExportRequest
from harbor_client.models.scan_overview import ScanOverview
from harbor_client.models.scanner import Scanner
from harbor_client.models.scanner_adapter_metadata import ScannerAdapterMetadata
from harbor_client.models.scanner_capability import ScannerCapability
from harbor_client.models.scanner_registration import ScannerRegistration
from harbor_client.models.scanner_registration_req import ScannerRegistrationReq
from harbor_client.models.scanner_registration_settings import ScannerRegistrationSettings
from harbor_client.models.schedule import Schedule
from harbor_client.models.schedule_obj import ScheduleObj
from harbor_client.models.schedule_task import ScheduleTask
from harbor_client.models.scheduler_status import SchedulerStatus
from harbor_client.models.search import Search
from harbor_client.models.search_repository import SearchRepository
from harbor_client.models.search_result import SearchResult
from harbor_client.models.start_replication_execution import StartReplicationExecution
from harbor_client.models.statistic import Statistic
from harbor_client.models.stats import Stats
from harbor_client.models.storage import Storage
from harbor_client.models.string_config_item import StringConfigItem
from harbor_client.models.supported_webhook_event_types import SupportedWebhookEventTypes
from harbor_client.models.system_info import SystemInfo
from harbor_client.models.tag import Tag
from harbor_client.models.task import Task
from harbor_client.models.user_creation_req import UserCreationReq
from harbor_client.models.user_entity import UserEntity
from harbor_client.models.user_group import UserGroup
from harbor_client.models.user_group_search_item import UserGroupSearchItem
from harbor_client.models.user_profile import UserProfile
from harbor_client.models.user_resp import UserResp
from harbor_client.models.user_search import UserSearch
from harbor_client.models.user_search_resp_item import UserSearchRespItem
from harbor_client.models.user_sys_admin_flag import UserSysAdminFlag
from harbor_client.models.vulnerability_summary import VulnerabilitySummary
from harbor_client.models.webhook_job import WebhookJob
from harbor_client.models.webhook_last_trigger import WebhookLastTrigger
from harbor_client.models.webhook_policy import WebhookPolicy
from harbor_client.models.webhook_target_object import WebhookTargetObject
from harbor_client.models.worker import Worker
from harbor_client.models.worker_pool import WorkerPool



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class RetentionPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'algorithm': 'str',
        'rules': 'list[RetentionRule]',
        'trigger': 'RetentionRuleTrigger',
        'scope': 'RetentionPolicyScope'
    }

    attribute_map = {
        'id': 'id',
        'algorithm': 'algorithm',
        'rules': 'rules',
        'trigger': 'trigger',
        'scope': 'scope'
    }

    def __init__(self, id=None, algorithm=None, rules=None, trigger=None, scope=None, _configuration=None):  # noqa: E501
        """RetentionPolicy - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._algorithm = None
        self._rules = None
        self._trigger = None
        self._scope = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if algorithm is not None:
            self.algorithm = algorithm
        if rules is not None:
            self.rules = rules
        if trigger is not None:
            self.trigger = trigger
        if scope is not None:
            self.scope = scope

    @property
    def id(self):
        """Gets the id of this RetentionPolicy.  # noqa: E501


        :return: The id of this RetentionPolicy.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RetentionPolicy.


        :param id: The id of this RetentionPolicy.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def algorithm(self):
        """Gets the algorithm of this RetentionPolicy.  # noqa: E501


        :return: The algorithm of this RetentionPolicy.  # noqa: E501
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """Sets the algorithm of this RetentionPolicy.


        :param algorithm: The algorithm of this RetentionPolicy.  # noqa: E501
        :type: str
        """

        self._algorithm = algorithm

    @property
    def rules(self):
        """Gets the rules of this RetentionPolicy.  # noqa: E501


        :return: The rules of this RetentionPolicy.  # noqa: E501
        :rtype: list[RetentionRule]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this RetentionPolicy.


        :param rules: The rules of this RetentionPolicy.  # noqa: E501
        :type: list[RetentionRule]
        """

        self._rules = rules

    @property
    def trigger(self):
        """Gets the trigger of this RetentionPolicy.  # noqa: E501


        :return: The trigger of this RetentionPolicy.  # noqa: E501
        :rtype: RetentionRuleTrigger
        """
        return self._trigger

    @trigger.setter
    def trigger(self, trigger):
        """Sets the trigger of this RetentionPolicy.


        :param trigger: The trigger of this RetentionPolicy.  # noqa: E501
        :type: RetentionRuleTrigger
        """

        self._trigger = trigger

    @property
    def scope(self):
        """Gets the scope of this RetentionPolicy.  # noqa: E501


        :return: The scope of this RetentionPolicy.  # noqa: E501
        :rtype: RetentionPolicyScope
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this RetentionPolicy.


        :param scope: The scope of this RetentionPolicy.  # noqa: E501
        :type: RetentionPolicyScope
        """

        self._scope = scope

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RetentionPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RetentionPolicy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RetentionPolicy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Search(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'project': 'list[Project]',
        'repository': 'list[SearchRepository]',
        'chart': 'list[SearchResult]'
    }

    attribute_map = {
        'project': 'project',
        'repository': 'repository',
        'chart': 'chart'
    }

    def __init__(self, project=None, repository=None, chart=None, _configuration=None):  # noqa: E501
        """Search - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._project = None
        self._repository = None
        self._chart = None
        self.discriminator = None

        if project is not None:
            self.project = project
        if repository is not None:
            self.repository = repository
        if chart is not None:
            self.chart = chart

    @property
    def project(self):
        """Gets the project of this Search.  # noqa: E501

        Search results of the projects that matched the filter keywords.  # noqa: E501

        :return: The project of this Search.  # noqa: E501
        :rtype: list[Project]
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this Search.

        Search results of the projects that matched the filter keywords.  # noqa: E501

        :param project: The project of this Search.  # noqa: E501
        :type: list[Project]
        """

        self._project = project

    @property
    def repository(self):
        """Gets the repository of this Search.  # noqa: E501

        Search results of the repositories that matched the filter keywords.  # noqa: E501

        :return: The repository of this Search.  # noqa: E501
        :rtype: list[SearchRepository]
        """
        return self._repository

    @repository.setter
    def repository(self, repository):
        """Sets the repository of this Search.

        Search results of the repositories that matched the filter keywords.  # noqa: E501

        :param repository: The repository of this Search.  # noqa: E501
        :type: list[SearchRepository]
        """

        self._repository = repository

    @property
    def chart(self):
        """Gets the chart of this Search.  # noqa: E501

        Search results of the charts that macthed the filter keywords.  # noqa: E501

        :return: The chart of this Search.  # noqa: E501
        :rtype: list[SearchResult]
        """
        return self._chart

    @chart.setter
    def chart(self, chart):
        """Sets the chart of this Search.

        Search results of the charts that macthed the filter keywords.  # noqa: E501

        :param chart: The chart of this Search.  # noqa: E501
        :type: list[SearchResult]
        """

        self._chart = chart

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Search, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Search):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Search):
            return True

        return self.to_dict() != other.to_dict()
